pub struct GetTransactionResponse {
pub transaction: Vec<u8>,
pub block_hash: Vec<u8>,
pub height: u32,
pub confirmations: u32,
pub is_instant_locked: bool,
pub is_chain_locked: bool,
}Fields
transaction: Vec<u8>block_hash: Vec<u8>height: u32confirmations: u32is_instant_locked: boolis_chain_locked: boolTrait Implementations
Sourceimpl Clone for GetTransactionResponse
impl Clone for GetTransactionResponse
Sourcefn clone(&self) -> GetTransactionResponse
fn clone(&self) -> GetTransactionResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetTransactionResponse
impl Debug for GetTransactionResponse
Sourceimpl Default for GetTransactionResponse
impl Default for GetTransactionResponse
Sourceimpl<'de> Deserialize<'de> for GetTransactionResponse
impl<'de> Deserialize<'de> for GetTransactionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for GetTransactionResponse
impl Hash for GetTransactionResponse
Sourceimpl Message for GetTransactionResponse
impl Message for GetTransactionResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Mockable for GetTransactionResponse
impl Mockable for GetTransactionResponse
Sourceimpl PartialEq for GetTransactionResponse
impl PartialEq for GetTransactionResponse
Sourceimpl Serialize for GetTransactionResponse
impl Serialize for GetTransactionResponse
impl Eq for GetTransactionResponse
impl StructuralPartialEq for GetTransactionResponse