pub enum Operation {
SetCredits(u64),
AddToCreditsOperations(AddToCreditsOperations),
}Variants
SetCredits(u64)
The address balance was set to this value (overwrites previous)
AddToCreditsOperations(AddToCreditsOperations)
Individual add-to-credits operations by block height (preserved for partial sync)
Implementations
Sourceimpl Operation
impl Operation
Sourcepub fn merge(
field: &mut Option<Operation>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Operation>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.