pub struct GetGroupInfosResponseV0 {
pub metadata: Option<ResponseMetadata>,
pub result: Option<Result>,
}Fields
metadata: Option<ResponseMetadata>result: Option<Result>Trait Implementations
Sourceimpl Clone for GetGroupInfosResponseV0
impl Clone for GetGroupInfosResponseV0
Sourcefn clone(&self) -> GetGroupInfosResponseV0
fn clone(&self) -> GetGroupInfosResponseV0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetGroupInfosResponseV0
impl Debug for GetGroupInfosResponseV0
Sourceimpl Default for GetGroupInfosResponseV0
impl Default for GetGroupInfosResponseV0
Sourceimpl<'de> Deserialize<'de> for GetGroupInfosResponseV0
impl<'de> Deserialize<'de> for GetGroupInfosResponseV0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetGroupInfosResponseV0> for GetGroupInfosResponse
impl From<GetGroupInfosResponseV0> for GetGroupInfosResponse
Sourcefn from(inner: GetGroupInfosResponseV0) -> Self
fn from(inner: GetGroupInfosResponseV0) -> Self
Converts to this type from the input type.
Sourceimpl Message for GetGroupInfosResponseV0
impl Message for GetGroupInfosResponseV0
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Mockable for GetGroupInfosResponseV0
impl Mockable for GetGroupInfosResponseV0
Sourceimpl PartialEq for GetGroupInfosResponseV0
impl PartialEq for GetGroupInfosResponseV0
Sourceimpl Serialize for GetGroupInfosResponseV0
impl Serialize for GetGroupInfosResponseV0
impl StructuralPartialEq for GetGroupInfosResponseV0
impl VersionedGrpcMessage<GetGroupInfosResponseV0> for GetGroupInfosResponse