pub struct GetStatusRequestV0 {}Trait Implementations
Sourceimpl Clone for GetStatusRequestV0
impl Clone for GetStatusRequestV0
Sourcefn clone(&self) -> GetStatusRequestV0
fn clone(&self) -> GetStatusRequestV0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetStatusRequestV0
impl Debug for GetStatusRequestV0
Sourceimpl Default for GetStatusRequestV0
impl Default for GetStatusRequestV0
Sourceimpl<'de> Deserialize<'de> for GetStatusRequestV0
impl<'de> Deserialize<'de> for GetStatusRequestV0
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetStatusRequestV0> for GetStatusRequest
impl From<GetStatusRequestV0> for GetStatusRequest
Sourcefn from(inner: GetStatusRequestV0) -> Self
fn from(inner: GetStatusRequestV0) -> Self
Converts to this type from the input type.
Sourceimpl Hash for GetStatusRequestV0
impl Hash for GetStatusRequestV0
Sourceimpl Message for GetStatusRequestV0
impl Message for GetStatusRequestV0
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Mockable for GetStatusRequestV0
impl Mockable for GetStatusRequestV0
Sourceimpl PartialEq for GetStatusRequestV0
impl PartialEq for GetStatusRequestV0
Sourceimpl Serialize for GetStatusRequestV0
impl Serialize for GetStatusRequestV0
impl Copy for GetStatusRequestV0
impl Eq for GetStatusRequestV0
impl StructuralPartialEq for GetStatusRequestV0
impl VersionedGrpcMessage<GetStatusRequestV0> for GetStatusRequest