PlatformClient

Struct PlatformClient 

pub struct PlatformClient<T> { /* private fields */ }

Implementations

Source

impl PlatformClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> PlatformClient<T>
where T: GrpcService<Body>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> PlatformClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>, <T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn broadcast_state_transition( &mut self, request: impl IntoRequest<BroadcastStateTransitionRequest>, ) -> Result<Response<BroadcastStateTransitionResponse>, Status>

@sdk-ignore: Write-only endpoint, not a query

pub async fn get_identity( &mut self, request: impl IntoRequest<GetIdentityRequest>, ) -> Result<Response<GetIdentityResponse>, Status>

pub async fn get_identity_keys( &mut self, request: impl IntoRequest<GetIdentityKeysRequest>, ) -> Result<Response<GetIdentityKeysResponse>, Status>

pub async fn get_identities_contract_keys( &mut self, request: impl IntoRequest<GetIdentitiesContractKeysRequest>, ) -> Result<Response<GetIdentitiesContractKeysResponse>, Status>

pub async fn get_identity_nonce( &mut self, request: impl IntoRequest<GetIdentityNonceRequest>, ) -> Result<Response<GetIdentityNonceResponse>, Status>

pub async fn get_identity_contract_nonce( &mut self, request: impl IntoRequest<GetIdentityContractNonceRequest>, ) -> Result<Response<GetIdentityContractNonceResponse>, Status>

pub async fn get_identity_balance( &mut self, request: impl IntoRequest<GetIdentityBalanceRequest>, ) -> Result<Response<GetIdentityBalanceResponse>, Status>

pub async fn get_identities_balances( &mut self, request: impl IntoRequest<GetIdentitiesBalancesRequest>, ) -> Result<Response<GetIdentitiesBalancesResponse>, Status>

pub async fn get_identity_balance_and_revision( &mut self, request: impl IntoRequest<GetIdentityBalanceAndRevisionRequest>, ) -> Result<Response<GetIdentityBalanceAndRevisionResponse>, Status>

pub async fn get_evonodes_proposed_epoch_blocks_by_ids( &mut self, request: impl IntoRequest<GetEvonodesProposedEpochBlocksByIdsRequest>, ) -> Result<Response<GetEvonodesProposedEpochBlocksResponse>, Status>

pub async fn get_evonodes_proposed_epoch_blocks_by_range( &mut self, request: impl IntoRequest<GetEvonodesProposedEpochBlocksByRangeRequest>, ) -> Result<Response<GetEvonodesProposedEpochBlocksResponse>, Status>

pub async fn get_data_contract( &mut self, request: impl IntoRequest<GetDataContractRequest>, ) -> Result<Response<GetDataContractResponse>, Status>

pub async fn get_data_contract_history( &mut self, request: impl IntoRequest<GetDataContractHistoryRequest>, ) -> Result<Response<GetDataContractHistoryResponse>, Status>

pub async fn get_data_contracts( &mut self, request: impl IntoRequest<GetDataContractsRequest>, ) -> Result<Response<GetDataContractsResponse>, Status>

pub async fn get_documents( &mut self, request: impl IntoRequest<GetDocumentsRequest>, ) -> Result<Response<GetDocumentsResponse>, Status>

pub async fn get_identity_by_public_key_hash( &mut self, request: impl IntoRequest<GetIdentityByPublicKeyHashRequest>, ) -> Result<Response<GetIdentityByPublicKeyHashResponse>, Status>

pub async fn get_identity_by_non_unique_public_key_hash( &mut self, request: impl IntoRequest<GetIdentityByNonUniquePublicKeyHashRequest>, ) -> Result<Response<GetIdentityByNonUniquePublicKeyHashResponse>, Status>

pub async fn wait_for_state_transition_result( &mut self, request: impl IntoRequest<WaitForStateTransitionResultRequest>, ) -> Result<Response<WaitForStateTransitionResultResponse>, Status>

pub async fn get_consensus_params( &mut self, request: impl IntoRequest<GetConsensusParamsRequest>, ) -> Result<Response<GetConsensusParamsResponse>, Status>

@sdk-ignore: Consensus params fetched via Tenderdash RPC

pub async fn get_protocol_version_upgrade_state( &mut self, request: impl IntoRequest<GetProtocolVersionUpgradeStateRequest>, ) -> Result<Response<GetProtocolVersionUpgradeStateResponse>, Status>

pub async fn get_protocol_version_upgrade_vote_status( &mut self, request: impl IntoRequest<GetProtocolVersionUpgradeVoteStatusRequest>, ) -> Result<Response<GetProtocolVersionUpgradeVoteStatusResponse>, Status>

pub async fn get_epochs_info( &mut self, request: impl IntoRequest<GetEpochsInfoRequest>, ) -> Result<Response<GetEpochsInfoResponse>, Status>

pub async fn get_finalized_epoch_infos( &mut self, request: impl IntoRequest<GetFinalizedEpochInfosRequest>, ) -> Result<Response<GetFinalizedEpochInfosResponse>, Status>

pub async fn get_contested_resources( &mut self, request: impl IntoRequest<GetContestedResourcesRequest>, ) -> Result<Response<GetContestedResourcesResponse>, Status>

What votes are currently happening for a specific contested index

pub async fn get_contested_resource_vote_state( &mut self, request: impl IntoRequest<GetContestedResourceVoteStateRequest>, ) -> Result<Response<GetContestedResourceVoteStateResponse>, Status>

What’s the state of a contested resource vote? (ie who is winning?)

pub async fn get_contested_resource_voters_for_identity( &mut self, request: impl IntoRequest<GetContestedResourceVotersForIdentityRequest>, ) -> Result<Response<GetContestedResourceVotersForIdentityResponse>, Status>

Who voted for a contested resource to go to a specific identity?

pub async fn get_contested_resource_identity_votes( &mut self, request: impl IntoRequest<GetContestedResourceIdentityVotesRequest>, ) -> Result<Response<GetContestedResourceIdentityVotesResponse>, Status>

How did an identity vote?

pub async fn get_vote_polls_by_end_date( &mut self, request: impl IntoRequest<GetVotePollsByEndDateRequest>, ) -> Result<Response<GetVotePollsByEndDateResponse>, Status>

What vote polls will end soon?

pub async fn get_prefunded_specialized_balance( &mut self, request: impl IntoRequest<GetPrefundedSpecializedBalanceRequest>, ) -> Result<Response<GetPrefundedSpecializedBalanceResponse>, Status>

pub async fn get_total_credits_in_platform( &mut self, request: impl IntoRequest<GetTotalCreditsInPlatformRequest>, ) -> Result<Response<GetTotalCreditsInPlatformResponse>, Status>

pub async fn get_path_elements( &mut self, request: impl IntoRequest<GetPathElementsRequest>, ) -> Result<Response<GetPathElementsResponse>, Status>

pub async fn get_status( &mut self, request: impl IntoRequest<GetStatusRequest>, ) -> Result<Response<GetStatusResponse>, Status>

pub async fn get_current_quorums_info( &mut self, request: impl IntoRequest<GetCurrentQuorumsInfoRequest>, ) -> Result<Response<GetCurrentQuorumsInfoResponse>, Status>

pub async fn get_identity_token_balances( &mut self, request: impl IntoRequest<GetIdentityTokenBalancesRequest>, ) -> Result<Response<GetIdentityTokenBalancesResponse>, Status>

pub async fn get_identities_token_balances( &mut self, request: impl IntoRequest<GetIdentitiesTokenBalancesRequest>, ) -> Result<Response<GetIdentitiesTokenBalancesResponse>, Status>

pub async fn get_identity_token_infos( &mut self, request: impl IntoRequest<GetIdentityTokenInfosRequest>, ) -> Result<Response<GetIdentityTokenInfosResponse>, Status>

pub async fn get_identities_token_infos( &mut self, request: impl IntoRequest<GetIdentitiesTokenInfosRequest>, ) -> Result<Response<GetIdentitiesTokenInfosResponse>, Status>

pub async fn get_token_statuses( &mut self, request: impl IntoRequest<GetTokenStatusesRequest>, ) -> Result<Response<GetTokenStatusesResponse>, Status>

pub async fn get_token_direct_purchase_prices( &mut self, request: impl IntoRequest<GetTokenDirectPurchasePricesRequest>, ) -> Result<Response<GetTokenDirectPurchasePricesResponse>, Status>

pub async fn get_token_contract_info( &mut self, request: impl IntoRequest<GetTokenContractInfoRequest>, ) -> Result<Response<GetTokenContractInfoResponse>, Status>

pub async fn get_token_pre_programmed_distributions( &mut self, request: impl IntoRequest<GetTokenPreProgrammedDistributionsRequest>, ) -> Result<Response<GetTokenPreProgrammedDistributionsResponse>, Status>

pub async fn get_token_perpetual_distribution_last_claim( &mut self, request: impl IntoRequest<GetTokenPerpetualDistributionLastClaimRequest>, ) -> Result<Response<GetTokenPerpetualDistributionLastClaimResponse>, Status>

pub async fn get_token_total_supply( &mut self, request: impl IntoRequest<GetTokenTotalSupplyRequest>, ) -> Result<Response<GetTokenTotalSupplyResponse>, Status>

pub async fn get_group_info( &mut self, request: impl IntoRequest<GetGroupInfoRequest>, ) -> Result<Response<GetGroupInfoResponse>, Status>

pub async fn get_group_infos( &mut self, request: impl IntoRequest<GetGroupInfosRequest>, ) -> Result<Response<GetGroupInfosResponse>, Status>

pub async fn get_group_actions( &mut self, request: impl IntoRequest<GetGroupActionsRequest>, ) -> Result<Response<GetGroupActionsResponse>, Status>

pub async fn get_group_action_signers( &mut self, request: impl IntoRequest<GetGroupActionSignersRequest>, ) -> Result<Response<GetGroupActionSignersResponse>, Status>

pub async fn get_address_info( &mut self, request: impl IntoRequest<GetAddressInfoRequest>, ) -> Result<Response<GetAddressInfoResponse>, Status>

pub async fn get_addresses_infos( &mut self, request: impl IntoRequest<GetAddressesInfosRequest>, ) -> Result<Response<GetAddressesInfosResponse>, Status>

pub async fn get_addresses_trunk_state( &mut self, request: impl IntoRequest<GetAddressesTrunkStateRequest>, ) -> Result<Response<GetAddressesTrunkStateResponse>, Status>

pub async fn get_addresses_branch_state( &mut self, request: impl IntoRequest<GetAddressesBranchStateRequest>, ) -> Result<Response<GetAddressesBranchStateResponse>, Status>

pub async fn get_recent_address_balance_changes( &mut self, request: impl IntoRequest<GetRecentAddressBalanceChangesRequest>, ) -> Result<Response<GetRecentAddressBalanceChangesResponse>, Status>

pub async fn get_recent_compacted_address_balance_changes( &mut self, request: impl IntoRequest<GetRecentCompactedAddressBalanceChangesRequest>, ) -> Result<Response<GetRecentCompactedAddressBalanceChangesResponse>, Status>

pub async fn get_shielded_encrypted_notes( &mut self, request: impl IntoRequest<GetShieldedEncryptedNotesRequest>, ) -> Result<Response<GetShieldedEncryptedNotesResponse>, Status>

pub async fn get_shielded_anchors( &mut self, request: impl IntoRequest<GetShieldedAnchorsRequest>, ) -> Result<Response<GetShieldedAnchorsResponse>, Status>

pub async fn get_most_recent_shielded_anchor( &mut self, request: impl IntoRequest<GetMostRecentShieldedAnchorRequest>, ) -> Result<Response<GetMostRecentShieldedAnchorResponse>, Status>

pub async fn get_shielded_pool_state( &mut self, request: impl IntoRequest<GetShieldedPoolStateRequest>, ) -> Result<Response<GetShieldedPoolStateResponse>, Status>

pub async fn get_shielded_nullifiers( &mut self, request: impl IntoRequest<GetShieldedNullifiersRequest>, ) -> Result<Response<GetShieldedNullifiersResponse>, Status>

pub async fn get_nullifiers_trunk_state( &mut self, request: impl IntoRequest<GetNullifiersTrunkStateRequest>, ) -> Result<Response<GetNullifiersTrunkStateResponse>, Status>

pub async fn get_nullifiers_branch_state( &mut self, request: impl IntoRequest<GetNullifiersBranchStateRequest>, ) -> Result<Response<GetNullifiersBranchStateResponse>, Status>

pub async fn get_recent_nullifier_changes( &mut self, request: impl IntoRequest<GetRecentNullifierChangesRequest>, ) -> Result<Response<GetRecentNullifierChangesResponse>, Status>

pub async fn get_recent_compacted_nullifier_changes( &mut self, request: impl IntoRequest<GetRecentCompactedNullifierChangesRequest>, ) -> Result<Response<GetRecentCompactedNullifierChangesResponse>, Status>