pub struct GetIdentitiesTokenBalancesRequest {
pub version: Option<Version>,
}Fields
version: Option<Version>Trait Implementations
Sourceimpl Clone for GetIdentitiesTokenBalancesRequest
impl Clone for GetIdentitiesTokenBalancesRequest
Sourcefn clone(&self) -> GetIdentitiesTokenBalancesRequest
fn clone(&self) -> GetIdentitiesTokenBalancesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for GetIdentitiesTokenBalancesRequest
impl<'de> Deserialize<'de> for GetIdentitiesTokenBalancesRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetIdentitiesTokenBalancesRequestV0> for GetIdentitiesTokenBalancesRequest
impl From<GetIdentitiesTokenBalancesRequestV0> for GetIdentitiesTokenBalancesRequest
Sourcefn from(inner: GetIdentitiesTokenBalancesRequestV0) -> Self
fn from(inner: GetIdentitiesTokenBalancesRequestV0) -> Self
Converts to this type from the input type.
Sourceimpl Message for GetIdentitiesTokenBalancesRequest
impl Message for GetIdentitiesTokenBalancesRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetIdentitiesTokenBalancesRequest
impl PartialEq for GetIdentitiesTokenBalancesRequest
Sourcefn eq(&self, other: &GetIdentitiesTokenBalancesRequest) -> bool
fn eq(&self, other: &GetIdentitiesTokenBalancesRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GetIdentitiesTokenBalancesRequest
impl StructuralPartialEq for GetIdentitiesTokenBalancesRequest
impl VersionedGrpcMessage<GetIdentitiesTokenBalancesRequestV0> for GetIdentitiesTokenBalancesRequest