pub struct GetIdentityKeysResponse {
pub version: Option<Version>,
}Fields
version: Option<Version>Trait Implementations
Sourceimpl Clone for GetIdentityKeysResponse
impl Clone for GetIdentityKeysResponse
Sourcefn clone(&self) -> GetIdentityKeysResponse
fn clone(&self) -> GetIdentityKeysResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetIdentityKeysResponse
impl Debug for GetIdentityKeysResponse
Sourceimpl Default for GetIdentityKeysResponse
impl Default for GetIdentityKeysResponse
Sourceimpl<'de> Deserialize<'de> for GetIdentityKeysResponse
impl<'de> Deserialize<'de> for GetIdentityKeysResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetIdentityKeysResponseV0> for GetIdentityKeysResponse
impl From<GetIdentityKeysResponseV0> for GetIdentityKeysResponse
Sourcefn from(inner: GetIdentityKeysResponseV0) -> Self
fn from(inner: GetIdentityKeysResponseV0) -> Self
Converts to this type from the input type.
Sourceimpl Hash for GetIdentityKeysResponse
impl Hash for GetIdentityKeysResponse
Sourceimpl Message for GetIdentityKeysResponse
impl Message for GetIdentityKeysResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Mockable for GetIdentityKeysResponse
impl Mockable for GetIdentityKeysResponse
Sourceimpl PartialEq for GetIdentityKeysResponse
impl PartialEq for GetIdentityKeysResponse
Sourceimpl Serialize for GetIdentityKeysResponse
impl Serialize for GetIdentityKeysResponse
impl Eq for GetIdentityKeysResponse
impl StructuralPartialEq for GetIdentityKeysResponse
impl VersionedGrpcMessage<GetIdentityKeysResponseV0> for GetIdentityKeysResponse