Message

Trait Message 

pub trait Message: Send + Sync {
    // Required methods
    fn encoded_len(&self) -> usize;
    fn clear(&mut self);

    // Provided methods
    fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>
       where Self: Sized { ... }
    fn encode_to_vec(&self) -> Vec<u8> 
       where Self: Sized { ... }
    fn encode_length_delimited(
        &self,
        buf: &mut impl BufMut,
    ) -> Result<(), EncodeError>
       where Self: Sized { ... }
    fn encode_length_delimited_to_vec(&self) -> Vec<u8> 
       where Self: Sized { ... }
    fn decode(buf: impl Buf) -> Result<Self, DecodeError>
       where Self: Default { ... }
    fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>
       where Self: Default { ... }
    fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>
       where Self: Sized { ... }
    fn merge_length_delimited(
        &mut self,
        buf: impl Buf,
    ) -> Result<(), DecodeError>
       where Self: Sized { ... }
}
A Protocol Buffers message.

Required Methods

fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.

fn clear(&mut self)

Clears the message, resetting all fields to their default.

Provided Methods

fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>
where Self: Sized,

Encodes the message to a buffer.

An error will be returned if the buffer does not have sufficient capacity.

fn encode_to_vec(&self) -> Vec<u8>
where Self: Sized,

Encodes the message to a newly allocated buffer.

fn encode_length_delimited( &self, buf: &mut impl BufMut, ) -> Result<(), EncodeError>
where Self: Sized,

Encodes the message with a length-delimiter to a buffer.

An error will be returned if the buffer does not have sufficient capacity.

fn encode_length_delimited_to_vec(&self) -> Vec<u8>
where Self: Sized,

Encodes the message with a length-delimiter to a newly allocated buffer.

fn decode(buf: impl Buf) -> Result<Self, DecodeError>
where Self: Default,

Decodes an instance of the message from a buffer.

The entire buffer will be consumed.

fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>
where Self: Default,

Decodes a length-delimited instance of the message from the buffer.

fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>
where Self: Sized,

Decodes an instance of the message from a buffer, and merges it into self.

The entire buffer will be consumed.

fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>
where Self: Sized,

Decodes a length-delimited instance of the message from buffer, and merges it into self.

Implementations on Foreign Types

Source

impl Message for bool

google.protobuf.BoolValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for f32

google.protobuf.FloatValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for f64

google.protobuf.DoubleValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for i32

google.protobuf.Int32Value

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for i64

google.protobuf.Int64Value

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for u32

google.protobuf.UInt32Value

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for u64

google.protobuf.UInt64Value

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ()

google.protobuf.Empty

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for String

google.protobuf.StringValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Vec<u8>

google.protobuf.BytesValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)



impl Message for AbciParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for AbciParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Block



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Block



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for BlockId



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for BlockId



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for BlockMeta



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for BlockMeta



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for BlockParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for BlockParams



fn encoded_len(&self) -> usize



fn clear(&mut self)

Source

impl Message for Bytes

google.protobuf.BytesValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)



impl Message for CanonicalBlockId



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalBlockId



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalPartSetHeader



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalPartSetHeader



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalVote



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalVote



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalVoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CanonicalVoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Commit



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Commit



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CommitInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CommitInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Consensus



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Consensus



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ConsensusParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ConsensusParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CoreChainLock



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for CoreChainLock



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Data



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Data



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for DominoOp



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for DominoOp



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for DuplicateVoteEvidence



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for DuplicateVoteEvidence



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Duration



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Event



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Event



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for EventAttribute



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for EventAttribute



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Evidence



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Evidence



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for EvidenceList



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for EvidenceList



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for EvidenceParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for EvidenceParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ExecTxResult



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ExecTxResult



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ExtendVoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ExtendVoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ExtendedVoteInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ExtendedVoteInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for HashedParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for HashedParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Header



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Header



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for LightBlock



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for LightBlock



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Misbehavior



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Misbehavior



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Part



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Part



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for PartSetHeader



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for PartSetHeader



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Proof



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Proof



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ProofOp



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ProofOp



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ProofOps



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ProofOps



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Proposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Proposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for PublicKey



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for PublicKey



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for QuorumHashUpdate



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for QuorumHashUpdate



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Request



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Request



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestApplySnapshotChunk



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestApplySnapshotChunk



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestCheckTx



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestCheckTx



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestEcho



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestEcho



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestExtendVote



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestExtendVote



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestFinalizeBlock



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestFinalizeBlock



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestFlush



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestFlush



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestInitChain



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestInitChain



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestListSnapshots



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestListSnapshots



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestLoadSnapshotChunk



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestLoadSnapshotChunk



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestOfferSnapshot



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestOfferSnapshot



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestPrepareProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestPrepareProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestProcessProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestProcessProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestQuery



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestQuery



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestVerifyVoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for RequestVerifyVoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Response



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Response



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseApplySnapshotChunk



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseApplySnapshotChunk



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseCheckTx



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseCheckTx



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseEcho



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseEcho



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseException



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseException



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseExtendVote



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseExtendVote



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseFinalizeBlock



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseFinalizeBlock



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseFlush



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseFlush



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseInitChain



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseInitChain



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseListSnapshots



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseListSnapshots



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseLoadSnapshotChunk



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseLoadSnapshotChunk



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseOfferSnapshot



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseOfferSnapshot



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponsePrepareProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponsePrepareProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseProcessProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseProcessProposal



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseQuery



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseQuery



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseVerifyVoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ResponseVerifyVoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for SignedHeader



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for SignedHeader



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for SimpleValidator



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for SimpleValidator



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Snapshot



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Snapshot



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for StateId



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for StateId



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for SynchronyParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for SynchronyParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ThresholdPublicKeyUpdate



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ThresholdPublicKeyUpdate



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for TimeoutParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for TimeoutParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Timestamp



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for TxProof



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for TxProof



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for TxRecord



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for TxRecord



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for TxResult



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for TxResult



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Validator



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Validator



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Validator



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Validator



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValidatorParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValidatorParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValidatorSet



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValidatorSet



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValidatorSetUpdate



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValidatorSetUpdate



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValidatorUpdate



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValidatorUpdate



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValueOp



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for ValueOp



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for VersionParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for VersionParams



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Vote



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for Vote



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for VoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for VoteExtension



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for VoteInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)



impl Message for VoteInfo



fn encoded_len(&self) -> usize



fn clear(&mut self)

Source

impl<M> Message for Box<M>
where M: Message,

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Implementors

Source

impl Message for dapi_grpc::core::v0::get_blockchain_status_response::Chain

Source

impl Message for dapi_grpc::core::v0::get_blockchain_status_response::Network

Source

impl Message for NetworkFee

Source

impl Message for dapi_grpc::core::v0::get_blockchain_status_response::Time

Source

impl Message for dapi_grpc::core::v0::get_blockchain_status_response::Version

Source

impl Message for BlockHeaders

Source

impl Message for BlockHeadersWithChainLocksRequest

Source

impl Message for BlockHeadersWithChainLocksResponse

Source

impl Message for BloomFilter

Source

impl Message for BroadcastTransactionRequest

Source

impl Message for BroadcastTransactionResponse

Source

impl Message for GetBestBlockHeightRequest

Source

impl Message for GetBestBlockHeightResponse

Source

impl Message for GetBlockRequest

Source

impl Message for GetBlockResponse

Source

impl Message for GetBlockchainStatusRequest

Source

impl Message for GetBlockchainStatusResponse

Source

impl Message for GetEstimatedTransactionFeeRequest

Source

impl Message for GetEstimatedTransactionFeeResponse

Source

impl Message for GetMasternodeStatusRequest

Source

impl Message for GetMasternodeStatusResponse

Source

impl Message for GetTransactionRequest

Source

impl Message for GetTransactionResponse

Source

impl Message for InstantSendLockMessages

Source

impl Message for MasternodeListRequest

Source

impl Message for MasternodeListResponse

Source

impl Message for RawTransactions

Source

impl Message for TransactionsWithProofsRequest

Source

impl Message for TransactionsWithProofsResponse

Source

impl Message for GetProofsRequest

Source

impl Message for GetProofsResponse

Source

impl Message for GetAddressInfoRequestV0

Source

impl Message for GetAddressInfoResponseV0

Source

impl Message for GetAddressesBranchStateRequestV0

Source

impl Message for GetAddressesBranchStateResponseV0

Source

impl Message for GetAddressesInfosRequestV0

Source

impl Message for GetAddressesInfosResponseV0

Source

impl Message for GetAddressesTrunkStateRequestV0

Source

impl Message for GetAddressesTrunkStateResponseV0

Source

impl Message for GetConsensusParamsRequestV0

Source

impl Message for ConsensusParamsBlock

Source

impl Message for ConsensusParamsEvidence

Source

impl Message for GetConsensusParamsResponseV0

Source

impl Message for StartAtVotePollIdInfo

Source

impl Message for GetContestedResourceIdentityVotesRequestV0

Source

impl Message for ContestedResourceIdentityVote

Source

impl Message for ContestedResourceIdentityVotes

Source

impl Message for ResourceVoteChoice

Source

impl Message for GetContestedResourceIdentityVotesResponseV0

Source

impl Message for dapi_grpc::platform::v0::get_contested_resource_vote_state_request::get_contested_resource_vote_state_request_v0::StartAtIdentifierInfo

Source

impl Message for GetContestedResourceVoteStateRequestV0

Source

impl Message for Contender

Source

impl Message for ContestedResourceContenders

Source

impl Message for FinishedVoteInfo

Source

impl Message for GetContestedResourceVoteStateResponseV0

Source

impl Message for dapi_grpc::platform::v0::get_contested_resource_voters_for_identity_request::get_contested_resource_voters_for_identity_request_v0::StartAtIdentifierInfo

Source

impl Message for GetContestedResourceVotersForIdentityRequestV0

Source

impl Message for ContestedResourceVoters

Source

impl Message for GetContestedResourceVotersForIdentityResponseV0

Source

impl Message for StartAtValueInfo

Source

impl Message for GetContestedResourcesRequestV0

Source

impl Message for ContestedResourceValues

Source

impl Message for GetContestedResourcesResponseV0

Source

impl Message for GetCurrentQuorumsInfoRequestV0

Source

impl Message for GetCurrentQuorumsInfoResponseV0

Source

impl Message for ValidatorSetV0

Source

impl Message for ValidatorV0

Source

impl Message for GetDataContractHistoryRequestV0

Source

impl Message for DataContractHistory

Source

impl Message for DataContractHistoryEntry

Source

impl Message for GetDataContractHistoryResponseV0

Source

impl Message for GetDataContractRequestV0

Source

impl Message for GetDataContractResponseV0

Source

impl Message for GetDataContractsRequestV0

Source

impl Message for DataContractEntry

Source

impl Message for DataContracts

Source

impl Message for GetDataContractsResponseV0

Source

impl Message for GetDocumentsRequestV0

Source

impl Message for Documents

Source

impl Message for GetDocumentsResponseV0

Source

impl Message for GetEpochsInfoRequestV0

Source

impl Message for EpochInfo

Source

impl Message for EpochInfos

Source

impl Message for GetEpochsInfoResponseV0

Source

impl Message for GetEvonodesProposedEpochBlocksByIdsRequestV0

Source

impl Message for GetEvonodesProposedEpochBlocksByRangeRequestV0

Source

impl Message for EvonodeProposedBlocks

Source

impl Message for EvonodesProposedBlocks

Source

impl Message for GetEvonodesProposedEpochBlocksResponseV0

Source

impl Message for GetFinalizedEpochInfosRequestV0

Source

impl Message for BlockProposer

Source

impl Message for FinalizedEpochInfo

Source

impl Message for FinalizedEpochInfos

Source

impl Message for GetFinalizedEpochInfosResponseV0

Source

impl Message for GetGroupActionSignersRequestV0

Source

impl Message for GroupActionSigner

Source

impl Message for GroupActionSigners

Source

impl Message for GetGroupActionSignersResponseV0

Source

impl Message for GetGroupActionsRequestV0

Source

impl Message for StartAtActionId

Source

impl Message for BurnEvent

Source

impl Message for ContractEvent

Source

impl Message for ContractUpdateEvent

Source

impl Message for DestroyFrozenFundsEvent

Source

impl Message for DocumentCreateEvent

Source

impl Message for DocumentEvent

Source

impl Message for EmergencyActionEvent

Source

impl Message for FreezeEvent

Source

impl Message for GroupActionEntry

Source

impl Message for GroupActionEvent

Source

impl Message for GroupActions

Source

impl Message for MintEvent

Source

impl Message for PersonalEncryptedNote

Source

impl Message for SharedEncryptedNote

Source

impl Message for TokenConfigUpdateEvent

Source

impl Message for TokenEvent

Source

impl Message for UnfreezeEvent

Source

impl Message for UpdateDirectPurchasePriceEvent

Source

impl Message for dapi_grpc::platform::v0::get_group_actions_response::get_group_actions_response_v0::update_direct_purchase_price_event::PriceForQuantity

Source

impl Message for dapi_grpc::platform::v0::get_group_actions_response::get_group_actions_response_v0::update_direct_purchase_price_event::PricingSchedule

Source

impl Message for GetGroupActionsResponseV0

Source

impl Message for GetGroupInfoRequestV0

Source

impl Message for GroupInfo

Source

impl Message for GroupInfoEntry

Source

impl Message for dapi_grpc::platform::v0::get_group_info_response::get_group_info_response_v0::GroupMemberEntry

Source

impl Message for GetGroupInfoResponseV0

Source

impl Message for GetGroupInfosRequestV0

Source

impl Message for StartAtGroupContractPosition

Source

impl Message for GroupInfos

Source

impl Message for dapi_grpc::platform::v0::get_group_infos_response::get_group_infos_response_v0::GroupMemberEntry

Source

impl Message for GroupPositionInfoEntry

Source

impl Message for GetGroupInfosResponseV0

Source

impl Message for GetIdentitiesBalancesRequestV0

Source

impl Message for IdentitiesBalances

Source

impl Message for IdentityBalance

Source

impl Message for GetIdentitiesBalancesResponseV0

Source

impl Message for GetIdentitiesContractKeysRequestV0

Source

impl Message for IdentitiesKeys

Source

impl Message for IdentityKeys

Source

impl Message for PurposeKeys

Source

impl Message for GetIdentitiesContractKeysResponseV0

Source

impl Message for GetIdentitiesTokenBalancesRequestV0

Source

impl Message for IdentityTokenBalanceEntry

Source

impl Message for IdentityTokenBalances

Source

impl Message for GetIdentitiesTokenBalancesResponseV0

Source

impl Message for GetIdentitiesTokenInfosRequestV0

Source

impl Message for IdentityTokenInfos

Source

impl Message for dapi_grpc::platform::v0::get_identities_token_infos_response::get_identities_token_infos_response_v0::TokenIdentityInfoEntry

Source

impl Message for dapi_grpc::platform::v0::get_identities_token_infos_response::get_identities_token_infos_response_v0::TokenInfoEntry

Source

impl Message for GetIdentitiesTokenInfosResponseV0

Source

impl Message for GetIdentityBalanceAndRevisionRequestV0

Source

impl Message for BalanceAndRevision

Source

impl Message for GetIdentityBalanceAndRevisionResponseV0

Source

impl Message for GetIdentityBalanceRequestV0

Source

impl Message for GetIdentityBalanceResponseV0

Source

impl Message for GetIdentityByNonUniquePublicKeyHashRequestV0

Source

impl Message for IdentityProvedResponse

Source

impl Message for IdentityResponse

Source

impl Message for GetIdentityByNonUniquePublicKeyHashResponseV0

Source

impl Message for GetIdentityByPublicKeyHashRequestV0

Source

impl Message for GetIdentityByPublicKeyHashResponseV0

Source

impl Message for GetIdentityContractNonceRequestV0

Source

impl Message for GetIdentityContractNonceResponseV0

Source

impl Message for GetIdentityKeysRequestV0

Source

impl Message for Keys

Source

impl Message for GetIdentityKeysResponseV0

Source

impl Message for GetIdentityNonceRequestV0

Source

impl Message for GetIdentityNonceResponseV0

Source

impl Message for GetIdentityRequestV0

Source

impl Message for GetIdentityResponseV0

Source

impl Message for GetIdentityTokenBalancesRequestV0

Source

impl Message for TokenBalanceEntry

Source

impl Message for TokenBalances

Source

impl Message for GetIdentityTokenBalancesResponseV0

Source

impl Message for GetIdentityTokenInfosRequestV0

Source

impl Message for dapi_grpc::platform::v0::get_identity_token_infos_response::get_identity_token_infos_response_v0::TokenIdentityInfoEntry

Source

impl Message for dapi_grpc::platform::v0::get_identity_token_infos_response::get_identity_token_infos_response_v0::TokenInfoEntry

Source

impl Message for TokenInfos

Source

impl Message for GetIdentityTokenInfosResponseV0

Source

impl Message for GetMostRecentShieldedAnchorRequestV0

Source

impl Message for GetMostRecentShieldedAnchorResponseV0

Source

impl Message for GetNullifiersBranchStateRequestV0

Source

impl Message for GetNullifiersBranchStateResponseV0

Source

impl Message for GetNullifiersTrunkStateRequestV0

Source

impl Message for GetNullifiersTrunkStateResponseV0

Source

impl Message for GetPathElementsRequestV0

Source

impl Message for Elements

Source

impl Message for GetPathElementsResponseV0

Source

impl Message for GetPrefundedSpecializedBalanceRequestV0

Source

impl Message for GetPrefundedSpecializedBalanceResponseV0

Source

impl Message for GetProtocolVersionUpgradeStateRequestV0

Source

impl Message for VersionEntry

Source

impl Message for Versions

Source

impl Message for GetProtocolVersionUpgradeStateResponseV0

Source

impl Message for GetProtocolVersionUpgradeVoteStatusRequestV0

Source

impl Message for VersionSignal

Source

impl Message for VersionSignals

Source

impl Message for GetProtocolVersionUpgradeVoteStatusResponseV0

Source

impl Message for GetRecentAddressBalanceChangesRequestV0

Source

impl Message for GetRecentAddressBalanceChangesResponseV0

Source

impl Message for GetRecentCompactedAddressBalanceChangesRequestV0

Source

impl Message for GetRecentCompactedAddressBalanceChangesResponseV0

Source

impl Message for GetRecentCompactedNullifierChangesRequestV0

Source

impl Message for GetRecentCompactedNullifierChangesResponseV0

Source

impl Message for GetRecentNullifierChangesRequestV0

Source

impl Message for GetRecentNullifierChangesResponseV0

Source

impl Message for GetShieldedAnchorsRequestV0

Source

impl Message for Anchors

Source

impl Message for GetShieldedAnchorsResponseV0

Source

impl Message for GetShieldedEncryptedNotesRequestV0

Source

impl Message for EncryptedNote

Source

impl Message for EncryptedNotes

Source

impl Message for GetShieldedEncryptedNotesResponseV0

Source

impl Message for GetShieldedNullifiersRequestV0

Source

impl Message for NullifierStatus

Source

impl Message for NullifierStatuses

Source

impl Message for GetShieldedNullifiersResponseV0

Source

impl Message for GetShieldedPoolStateRequestV0

Source

impl Message for GetShieldedPoolStateResponseV0

Source

impl Message for GetStatusRequestV0

Source

impl Message for dapi_grpc::platform::v0::get_status_response::get_status_response_v0::Chain

Source

impl Message for dapi_grpc::platform::v0::get_status_response::get_status_response_v0::Network

Source

impl Message for Node

Source

impl Message for StateSync

Source

impl Message for dapi_grpc::platform::v0::get_status_response::get_status_response_v0::Time

Source

impl Message for dapi_grpc::platform::v0::get_status_response::get_status_response_v0::Version

Source

impl Message for Drive

Source

impl Message for Tenderdash

Source

impl Message for Protocol

Source

impl Message for Software

Source

impl Message for GetStatusResponseV0

Source

impl Message for GetTokenContractInfoRequestV0

Source

impl Message for TokenContractInfoData

Source

impl Message for GetTokenContractInfoResponseV0

Source

impl Message for GetTokenDirectPurchasePricesRequestV0

Source

impl Message for dapi_grpc::platform::v0::get_token_direct_purchase_prices_response::get_token_direct_purchase_prices_response_v0::PriceForQuantity

Source

impl Message for dapi_grpc::platform::v0::get_token_direct_purchase_prices_response::get_token_direct_purchase_prices_response_v0::PricingSchedule

Source

impl Message for TokenDirectPurchasePriceEntry

Source

impl Message for TokenDirectPurchasePrices

Source

impl Message for GetTokenDirectPurchasePricesResponseV0

Source

impl Message for ContractTokenInfo

Source

impl Message for GetTokenPerpetualDistributionLastClaimRequestV0

Source

impl Message for LastClaimInfo

Source

impl Message for GetTokenPerpetualDistributionLastClaimResponseV0

Source

impl Message for StartAtInfo

Source

impl Message for GetTokenPreProgrammedDistributionsRequestV0

Source

impl Message for TokenDistributionEntry

Source

impl Message for TokenDistributions

Source

impl Message for TokenTimedDistributionEntry

Source

impl Message for GetTokenPreProgrammedDistributionsResponseV0

Source

impl Message for GetTokenStatusesRequestV0

Source

impl Message for TokenStatusEntry

Source

impl Message for TokenStatuses

Source

impl Message for GetTokenStatusesResponseV0

Source

impl Message for GetTokenTotalSupplyRequestV0

Source

impl Message for TokenTotalSupplyEntry

Source

impl Message for GetTokenTotalSupplyResponseV0

Source

impl Message for GetTotalCreditsInPlatformRequestV0

Source

impl Message for GetTotalCreditsInPlatformResponseV0

Source

impl Message for EndAtTimeInfo

Source

impl Message for StartAtTimeInfo

Source

impl Message for GetVotePollsByEndDateRequestV0

Source

impl Message for SerializedVotePollsByTimestamp

Source

impl Message for SerializedVotePollsByTimestamps

Source

impl Message for GetVotePollsByEndDateResponseV0

Source

impl Message for AddToCreditsOperations

Source

impl Message for AddressBalanceChange

Source

impl Message for AddressBalanceUpdateEntries

Source

impl Message for AddressInfoEntries

Source

impl Message for AddressInfoEntry

Source

impl Message for AllKeys

Source

impl Message for BalanceAndNonce

Source

impl Message for BlockAddressBalanceChanges

Source

impl Message for BlockHeightCreditEntry

Source

impl Message for BlockNullifierChanges

Source

impl Message for BroadcastStateTransitionRequest

Source

impl Message for BroadcastStateTransitionResponse

Source

impl Message for CompactedAddressBalanceChange

Source

impl Message for CompactedAddressBalanceUpdateEntries

Source

impl Message for CompactedBlockAddressBalanceChanges

Source

impl Message for CompactedBlockNullifierChanges

Source

impl Message for CompactedNullifierUpdateEntries

Source

impl Message for GetAddressInfoRequest

Source

impl Message for GetAddressInfoResponse

Source

impl Message for GetAddressesBranchStateRequest

Source

impl Message for GetAddressesBranchStateResponse

Source

impl Message for GetAddressesInfosRequest

Source

impl Message for GetAddressesInfosResponse

Source

impl Message for GetAddressesTrunkStateRequest

Source

impl Message for GetAddressesTrunkStateResponse

Source

impl Message for GetConsensusParamsRequest

Source

impl Message for GetConsensusParamsResponse

Source

impl Message for GetContestedResourceIdentityVotesRequest

Source

impl Message for GetContestedResourceIdentityVotesResponse

Source

impl Message for GetContestedResourceVoteStateRequest

Source

impl Message for GetContestedResourceVoteStateResponse

Source

impl Message for GetContestedResourceVotersForIdentityRequest

Source

impl Message for GetContestedResourceVotersForIdentityResponse

Source

impl Message for GetContestedResourcesRequest

Source

impl Message for GetContestedResourcesResponse

Source

impl Message for GetCurrentQuorumsInfoRequest

Source

impl Message for GetCurrentQuorumsInfoResponse

Source

impl Message for GetDataContractHistoryRequest

Source

impl Message for GetDataContractHistoryResponse

Source

impl Message for GetDataContractRequest

Source

impl Message for GetDataContractResponse

Source

impl Message for GetDataContractsRequest

Source

impl Message for GetDataContractsResponse

Source

impl Message for GetDocumentsRequest

Source

impl Message for GetDocumentsResponse

Source

impl Message for GetEpochsInfoRequest

Source

impl Message for GetEpochsInfoResponse

Source

impl Message for GetEvonodesProposedEpochBlocksByIdsRequest

Source

impl Message for GetEvonodesProposedEpochBlocksByRangeRequest

Source

impl Message for GetEvonodesProposedEpochBlocksResponse

Source

impl Message for GetFinalizedEpochInfosRequest

Source

impl Message for GetFinalizedEpochInfosResponse

Source

impl Message for GetGroupActionSignersRequest

Source

impl Message for GetGroupActionSignersResponse

Source

impl Message for GetGroupActionsRequest

Source

impl Message for GetGroupActionsResponse

Source

impl Message for GetGroupInfoRequest

Source

impl Message for GetGroupInfoResponse

Source

impl Message for GetGroupInfosRequest

Source

impl Message for GetGroupInfosResponse

Source

impl Message for GetIdentitiesBalancesRequest

Source

impl Message for GetIdentitiesBalancesResponse

Source

impl Message for GetIdentitiesContractKeysRequest

Source

impl Message for GetIdentitiesContractKeysResponse

Source

impl Message for GetIdentitiesTokenBalancesRequest

Source

impl Message for GetIdentitiesTokenBalancesResponse

Source

impl Message for GetIdentitiesTokenInfosRequest

Source

impl Message for GetIdentitiesTokenInfosResponse

Source

impl Message for GetIdentityBalanceAndRevisionRequest

Source

impl Message for GetIdentityBalanceAndRevisionResponse

Source

impl Message for GetIdentityBalanceRequest

Source

impl Message for GetIdentityBalanceResponse

Source

impl Message for GetIdentityByNonUniquePublicKeyHashRequest

Source

impl Message for GetIdentityByNonUniquePublicKeyHashResponse

Source

impl Message for GetIdentityByPublicKeyHashRequest

Source

impl Message for GetIdentityByPublicKeyHashResponse

Source

impl Message for GetIdentityContractNonceRequest

Source

impl Message for GetIdentityContractNonceResponse

Source

impl Message for GetIdentityKeysRequest

Source

impl Message for GetIdentityKeysResponse

Source

impl Message for GetIdentityNonceRequest

Source

impl Message for GetIdentityNonceResponse

Source

impl Message for GetIdentityRequest

Source

impl Message for GetIdentityResponse

Source

impl Message for GetIdentityTokenBalancesRequest

Source

impl Message for GetIdentityTokenBalancesResponse

Source

impl Message for GetIdentityTokenInfosRequest

Source

impl Message for GetIdentityTokenInfosResponse

Source

impl Message for GetMostRecentShieldedAnchorRequest

Source

impl Message for GetMostRecentShieldedAnchorResponse

Source

impl Message for GetNullifiersBranchStateRequest

Source

impl Message for GetNullifiersBranchStateResponse

Source

impl Message for GetNullifiersTrunkStateRequest

Source

impl Message for GetNullifiersTrunkStateResponse

Source

impl Message for GetPathElementsRequest

Source

impl Message for GetPathElementsResponse

Source

impl Message for GetPrefundedSpecializedBalanceRequest

Source

impl Message for GetPrefundedSpecializedBalanceResponse

Source

impl Message for GetProtocolVersionUpgradeStateRequest

Source

impl Message for GetProtocolVersionUpgradeStateResponse

Source

impl Message for GetProtocolVersionUpgradeVoteStatusRequest

Source

impl Message for GetProtocolVersionUpgradeVoteStatusResponse

Source

impl Message for GetRecentAddressBalanceChangesRequest

Source

impl Message for GetRecentAddressBalanceChangesResponse

Source

impl Message for GetRecentCompactedAddressBalanceChangesRequest

Source

impl Message for GetRecentCompactedAddressBalanceChangesResponse

Source

impl Message for GetRecentCompactedNullifierChangesRequest

Source

impl Message for GetRecentCompactedNullifierChangesResponse

Source

impl Message for GetRecentNullifierChangesRequest

Source

impl Message for GetRecentNullifierChangesResponse

Source

impl Message for GetShieldedAnchorsRequest

Source

impl Message for GetShieldedAnchorsResponse

Source

impl Message for GetShieldedEncryptedNotesRequest

Source

impl Message for GetShieldedEncryptedNotesResponse

Source

impl Message for GetShieldedNullifiersRequest

Source

impl Message for GetShieldedNullifiersResponse

Source

impl Message for GetShieldedPoolStateRequest

Source

impl Message for GetShieldedPoolStateResponse

Source

impl Message for GetStatusRequest

Source

impl Message for GetStatusResponse

Source

impl Message for GetTokenContractInfoRequest

Source

impl Message for GetTokenContractInfoResponse

Source

impl Message for GetTokenDirectPurchasePricesRequest

Source

impl Message for GetTokenDirectPurchasePricesResponse

Source

impl Message for GetTokenPerpetualDistributionLastClaimRequest

Source

impl Message for GetTokenPerpetualDistributionLastClaimResponse

Source

impl Message for GetTokenPreProgrammedDistributionsRequest

Source

impl Message for GetTokenPreProgrammedDistributionsResponse

Source

impl Message for GetTokenStatusesRequest

Source

impl Message for GetTokenStatusesResponse

Source

impl Message for GetTokenTotalSupplyRequest

Source

impl Message for GetTokenTotalSupplyResponse

Source

impl Message for GetTotalCreditsInPlatformRequest

Source

impl Message for GetTotalCreditsInPlatformResponse

Source

impl Message for GetVotePollsByEndDateRequest

Source

impl Message for GetVotePollsByEndDateResponse

Source

impl Message for KeyRequestType

Source

impl Message for NullifierUpdateEntries

Source

impl Message for dapi_grpc::platform::v0::Proof

Source

impl Message for ResponseMetadata

Source

impl Message for SearchKey

Source

impl Message for SecurityLevelMap

Source

impl Message for SpecificKeys

Source

impl Message for StateTransitionBroadcastError

Source

impl Message for WaitForStateTransitionResultRequest

Source

impl Message for WaitForStateTransitionResultResponse

Source

impl Message for WaitForStateTransitionResultRequestV0

Source

impl Message for WaitForStateTransitionResultResponseV0